package sun.awt.windows;

import sun.security.action.GetPropertyAction;
import java.awt.peer.ComponentPeer;
import java.awt.Dialog;
import java.awt.AWTKeyStroke;
import java.awt.event.InvocationEvent;
import sun.awt.SunToolkit;
import java.awt.EventQueue;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.awt.Graphics;
import sun.awt.image.ByteInterleavedRaster;
import java.awt.Graphics2D;
import java.awt.Color;
import java.awt.image.BufferedImage;
import java.awt.Toolkit;
import sun.awt.EmbeddedFrame;

public class WEmbeddedFrame extends EmbeddedFrame
{
    private long handle;
    private int bandWidth;
    private int bandHeight;
    private int imgWid;
    private int imgHgt;
    private static int pScale;
    private static final int MAX_BAND_SIZE = 30720;
    private boolean isEmbeddedInIE;
    private static String printScale;
    
    public WEmbeddedFrame() {
        this(0L);
    }
    
    @Deprecated
    public WEmbeddedFrame(int n) {
        this((long)n);
    }
    
    public WEmbeddedFrame(long handle) {
        this.bandWidth = 0;
        this.bandHeight = 0;
        this.imgWid = 0;
        this.imgHgt = 0;
        this.isEmbeddedInIE = false;
        this.handle = handle;
        if (handle != 0L) {
            this.addNotify();
            this.show();
        }
    }
    
    @Override
    public void addNotify() {
        if (this.getPeer() == null) {
            this.setPeer(((WToolkit)Toolkit.getDefaultToolkit()).createEmbeddedFrame(this));
        }
        super.addNotify();
    }
    
    public long getEmbedderHandle() {
        return this.handle;
    }
    
    void print(long n) {
        Object o = null;
        int printScaleFactor = 1;
        int n2 = 1;
        if (this.isPrinterDC(n)) {
            n2 = (printScaleFactor = getPrintScaleFactor());
        }
        int height = this.getHeight();
        if (o == null) {
            this.bandWidth = this.getWidth();
            if (this.bandWidth % 4 != 0) {
                this.bandWidth += 4 - this.bandWidth % 4;
            }
            if (this.bandWidth <= 0) {
                return;
            }
            this.bandHeight = Math.min(30720 / this.bandWidth, height);
            this.imgWid = this.bandWidth * printScaleFactor;
            this.imgHgt = this.bandHeight * n2;
            o = new BufferedImage(this.imgWid, this.imgHgt, 5);
        }
        Graphics graphics = o.getGraphics();
        graphics.setColor(Color.white);
        Graphics2D g = (Graphics2D)o.getGraphics();
        g.translate(0, this.imgHgt);
        g.scale((double)printScaleFactor, (double)(-n2));
        byte[] dataStorage = ((ByteInterleavedRaster)o.getRaster()).getDataStorage();
        for (int i = 0; i < height; i += this.bandHeight) {
            graphics.fillRect(0, 0, this.bandWidth, this.bandHeight);
            this.printComponents(g);
            int n3 = 0;
            int bandHeight = this.bandHeight;
            int imgHgt = this.imgHgt;
            if (i + this.bandHeight > height) {
                bandHeight = height - i;
                imgHgt = bandHeight * n2;
                n3 = this.imgWid * (this.imgHgt - imgHgt) * 3;
            }
            this.printBand(n, dataStorage, n3, 0, 0, this.imgWid, imgHgt, 0, i, this.bandWidth, bandHeight);
            g.translate(0, -this.bandHeight);
        }
    }
    
    protected static int getPrintScaleFactor() {
        if (WEmbeddedFrame.pScale != 0) {
            return WEmbeddedFrame.pScale;
        }
        if (WEmbeddedFrame.printScale == null) {
            WEmbeddedFrame.printScale = (String)AccessController.doPrivileged(new PrivilegedAction<String>() {
                @Override
                public String run() {
                    return System.getenv("JAVA2D_PLUGIN_PRINT_SCALE");
                }
            });
        }
        int int1 = 4;
        if (WEmbeddedFrame.printScale != null) {
            try {
                int1 = Integer.parseInt(WEmbeddedFrame.printScale);
                if (int1 > 8 || int1 < 1) {
                }
            }
            catch (NumberFormatException ex) {}
        }
        return WEmbeddedFrame.pScale = int1;
    }
    
    private native boolean isPrinterDC(long p0);
    
    private native void printBand(long p0, byte[] p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, int p9, int p10);
    
    private static native void initIDs();
    
    public void activateEmbeddingTopLevel() {
    }
    
    @Override
    public void synthesizeWindowActivation(boolean b) {
        if (!b || EventQueue.isDispatchThread()) {
            ((WFramePeer)this.getPeer()).emulateActivation(b);
        }
        else {
            SunToolkit.postEvent(SunToolkit.targetToAppContext(this), new InvocationEvent(this, new Runnable() {
                @Override
                public void run() {
                    ((WFramePeer)WEmbeddedFrame.this.getPeer()).emulateActivation(true);
                }
            }));
        }
    }
    
    @Override
    public void registerAccelerator(AWTKeyStroke awtKeyStroke) {
    }
    
    @Override
    public void unregisterAccelerator(AWTKeyStroke awtKeyStroke) {
    }
    
    @Override
    public void notifyModalBlocked(Dialog dialog, boolean b) {
        try {
            this.notifyModalBlockedImpl((WEmbeddedFramePeer)(ComponentPeer)WToolkit.targetToPeer(this), (WWindowPeer)(ComponentPeer)WToolkit.targetToPeer(dialog), b);
        }
        catch (Exception ex) {
            ex.printStackTrace(System.err);
        }
    }
    
    native void notifyModalBlockedImpl(WEmbeddedFramePeer p0, WWindowPeer p1, boolean p2);
    
    static {
        initIDs();
        WEmbeddedFrame.pScale = 0;
        WEmbeddedFrame.printScale = (String)AccessController.doPrivileged(new GetPropertyAction("sun.java2d.print.pluginscalefactor"));
    }
}
